@@ -67,24 +67,6 @@ void start_level(TangleButton* button,gpointer data) {
 }
 
 
-gboolean on_start_button_clicked(JammoGameLevel* game_level, TangleButton* button) {
-	const gchar* name;
-	name = clutter_actor_get_name(CLUTTER_ACTOR(button));
-	printf("name is '%s'\n",name);
-
-
-	ClutterActor* mainview;
-	mainview = jammo_get_actor_by_id("main-views-widget");
-	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
-
-
-	jammo_game_level_start_task(game_level, name);
-	clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));
-
-	return FALSE;
-}
-
-
 void all_levels_completed(JammoGameLevel* game_level) {
 	g_print("MENTOR: Now you have gone through all game levels! Feel free to do whatever you want now on...\n");
 }
