@@ -51,6 +51,20 @@ static int length_of_melodics=0;
 static int length_of_harmonics=0;
 static int length_of_effects=0;
 
+static JammoSampleType type_by_id(int id) {
+JammoSampleType type=JAMMO_SAMPLE_UNTYPED;
+ if (id>=1000 && id <2000){
+		type=JAMMO_SAMPLE_RHYTMICAL;
+	} else if (id>=2000 && id <3000) {
+		type=JAMMO_SAMPLE_MELODICAL;
+	} else if (id>=3000 && id <4000) {
+		type=JAMMO_SAMPLE_HARMONICAL;
+	}	else if (id>=4000 && id <5000) {
+		type=JAMMO_SAMPLE_EFFECT;
+	}
+	return type;
+}
+
 gboolean sequencer_lock_pressed (TangleButton* tanglebutton, gpointer data){
 
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
@@ -775,10 +789,11 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 
 	while(new_button.image){
 		ClutterActor* sample_button;
+		int loop_id = counter+loop_type;
 		gchar* full_image = tangle_lookup_filename(new_button.image);
 		gchar* full_sound = g_strdup_printf("%s", new_button.sound);
 		//printf("new_sample: '%s', '%s'\n",full_image,full_sound);
-		sample_button = jammo_sample_button_new(); //TODO: jammo_sample_button_new_with_type
+		sample_button = jammo_sample_button_new_with_type(type_by_id(loop_id));
 		g_object_set(sample_button,"sequencer", jammo_get_object_by_id("fullsequencer-the-sequencer"),NULL);
 
 		//With clutter-1.4 samplebutton should be in container before image_filename is set
@@ -789,7 +804,6 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 		jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 		jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button), full_sound);
 
-		int loop_id = counter+loop_type;
 
 
 		g_object_set(sample_button,"drag-threshold-y",10000,NULL); //No dragging by vertical-axis (it is for scrolling wheel)
@@ -810,7 +824,15 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 	return counter;
 }
 
-
+ClutterActor* sequencer_loop_get_nth_sample_looper(int index) {
+	switch (index) {
+		case 1: return rhytmical_sample_looper;
+		case 2: return melodical_sample_looper;
+		case 3: return harmonical_sample_looper;
+		case 4: return effect_sample_looper;
+		default: return NULL;
+	}
+}
 
 void sequencer_loop_tune_wheels(int level_number) {
 	//Static controls-for-edit1$mute-button
@@ -882,7 +904,8 @@ ClutterActor* sequencer_loop_give_sample_button_for_this_id(guint id){
 	gchar* full_image = tangle_lookup_filename(new_button.image);
 	gchar* full_sound = g_strdup_printf("%s/%s", DATA_DIR,new_button.sound);
 	//printf("new_sample: '%s', '%s'\n",full_image,full_sound);
-	sample_button = jammo_sample_button_new(); //TODO: jammo_sample_button_new_with_type
+	sample_button = jammo_sample_button_new_with_type(type_by_id(id));
+
 	//g_object_set(sample_button,"sequencer", jammo_get_object_by_id("fullsequencer-the-sequencer"),NULL);
 	jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 	jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button), full_sound);
