@@ -69,6 +69,7 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 	if (JAMMO_IS_MIDITRACK_VIEW(track_view))
 	{
 		printf("It is instrument track\n");
+		tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
 		//We can start realtime jamming or midi-editor.
 		//Midi-editor backs always to sequencer.
 		//From Jamming we can go back to sequencer or reach editor
@@ -78,7 +79,8 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 		instrument_gui_start(JAMMO_MIDITRACK_VIEW(track_view), NULL); //NULL means no slider
 
 		//editor
-		//midi_editor_start_with_miditrack_view(JAMMO_MIDITRACK_VIEW(track->track_view));
+		//JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+		//midi_editor_start_with_miditrack_view(JAMMO_MIDITRACK_VIEW(track_view), sequencer);
 	}
 	else if (JAMMO_IS_TRACK_VIEW(track_view))
 	{
@@ -88,6 +90,7 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 		g_object_get(track_view,"track",&track,NULL);
 		if (JAMMO_IS_SLIDER_TRACK(track)) {
 			printf(" it is slider_track\n");
+			tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
 			instrument_gui_start(NULL, container2); //NULL means no keyboard, but slider
 		}
 		else if (JAMMO_IS_BACKING_TRACK(track)){
